@@ -29,10 +29,6 @@
 #include "actions.h"        //::seek() FIXME unfortunate
 #include "theStream.h"
 
-#ifdef HAVE_XINE
-#include <xine.h>
-#endif
-
 #include <QActionGroup>
 #include <QContextMenuEvent>
 #include <QLabel>
@@ -49,6 +45,7 @@
 #include <KStandardDirs>
 
 #include <Phonon/AudioOutput>
+#include <phonon/audiodataoutput.h>
 #include <Phonon/MediaController>
 #include <Phonon/MediaObject>
 #include <Phonon/MediaSource>
@@ -87,16 +84,16 @@ VideoWindow::VideoWindow( QWidget *parent )
         , m_cursorTimer( new QTimer( this ) )
         , m_justLoaded( false )
         , m_adjustedSize( false)
-        , m_xineStream( 0 )
         , m_subLanguages( new QActionGroup( this ) )
         , m_audioLanguages( new QActionGroup( this ) )
         , m_logo( new QLabel( this ) )
+        , m_aDataOutput(0)
 {
-    
+
     m_isPreview = false;
 
     s_instance = this;
-    setObjectName( "VideoWindow" );
+    setObjectName( QLatin1String( "VideoWindow" ) );
 
     QVBoxLayout *box = new QVBoxLayout( this );
     box->setMargin(0);
@@ -110,24 +107,24 @@ VideoWindow::VideoWindow( QWidget *parent )
     Phonon::createPath(m_media, m_vWidget);
     m_audioPath = Phonon::createPath(m_media, m_aOutput);
     m_media->setTickInterval( 1000 );
-    connect( m_media, SIGNAL( tick( qint64 ) ), this, SIGNAL( tick( qint64 ) ) );
-    connect( m_media, SIGNAL( currentSourceChanged( Phonon::MediaSource ) ), this, SIGNAL( currentSourceChanged( Phonon::MediaSource ) ) );
-    connect( m_media, SIGNAL( totalTimeChanged( qint64 ) ), this, SIGNAL( totalTimeChanged( qint64 ) ) );
-    connect( m_media, SIGNAL( seekableChanged( bool ) ), this, SIGNAL( seekableChanged( bool ) ) );
-    connect( m_media, SIGNAL( metaDataChanged() ), this, SIGNAL( metaDataChanged() ) );
-    connect( m_aOutput, SIGNAL( mutedChanged( bool ) ), this, SIGNAL( mutedChanged( bool ) ) );
-    connect( m_media, SIGNAL( hasVideoChanged( bool ) ), this, SIGNAL( hasVideoChanged( bool ) ) );
-    connect( m_media, SIGNAL( hasVideoChanged( bool ) ), m_vWidget, SLOT( setVisible( bool ) ) ); //hide video widget if no video to show
-    connect( m_media, SIGNAL( hasVideoChanged( bool ) ), m_logo, SLOT( setHidden( bool ) ) );
+    connect( m_media, SIGNAL(tick(qint64)), this, SIGNAL(tick(qint64)) );
+    connect( m_media, SIGNAL(currentSourceChanged(Phonon::MediaSource)), this, SIGNAL(currentSourceChanged(Phonon::MediaSource)) );
+    connect( m_media, SIGNAL(totalTimeChanged(qint64)), this, SIGNAL(totalTimeChanged(qint64)) );
+    connect( m_media, SIGNAL(seekableChanged(bool)), this, SIGNAL(seekableChanged(bool)) );
+    connect( m_media, SIGNAL(metaDataChanged()), this, SIGNAL(metaDataChanged()) );
+    connect( m_aOutput, SIGNAL(mutedChanged(bool)), this, SIGNAL(mutedChanged(bool)) );
+    connect( m_media, SIGNAL(hasVideoChanged(bool)), this, SIGNAL(hasVideoChanged(bool)) );
+    connect( m_media, SIGNAL(hasVideoChanged(bool)), m_vWidget, SLOT(setVisible(bool)) ); //hide video widget if no video to show
+    connect( m_media, SIGNAL(hasVideoChanged(bool)), m_logo, SLOT(setHidden(bool)) );
 
-    connect( m_controller, SIGNAL( availableSubtitlesChanged() ), this, SLOT( updateChannels() ) );
+    connect( m_controller, SIGNAL(availableSubtitlesChanged()), this, SLOT(updateChannels()) );
 
     {
         m_subLanguages->setExclusive( true );
         QAction* turnOff = new QAction( i18n("&DVD Subtitle Selection"), m_subLanguages );
         turnOff->setCheckable( true );
         turnOff->setProperty( TheStream::CHANNEL_PROPERTY, -1 );
-        connect( turnOff, SIGNAL( triggered() ), this, SLOT( slotSetSubtitle() ) );
+        connect( turnOff, SIGNAL(triggered()), this, SLOT(slotSetSubtitle()) );
 
         QAction* separator = new QAction( m_subLanguages );
         separator->setSeparator( true );
@@ -137,14 +134,14 @@ VideoWindow::VideoWindow( QWidget *parent )
         QAction* autoLang = new QAction( i18n("&Auto"), m_audioLanguages );
         autoLang->setProperty( TheStream::CHANNEL_PROPERTY, -1 );
         autoLang->setCheckable( true );
-        connect( autoLang, SIGNAL( triggered() ), this, SLOT( slotSetAudio() ) );
+        connect( autoLang, SIGNAL(triggered()), this, SLOT(slotSetAudio()) );
 
         QAction* separator = new QAction( m_audioLanguages );
         separator->setSeparator( true );
     }
 
     connect( m_media, SIGNAL(stateChanged(Phonon::State,Phonon::State)), this, SLOT(stateChanged(Phonon::State,Phonon::State)) );
-    connect( m_cursorTimer, SIGNAL( timeout() ), this, SLOT( hideCursor() ) );
+    connect( m_cursorTimer, SIGNAL(timeout()), this, SLOT(hideCursor()) );
     m_cursorTimer->setSingleShot( true );
     {
         m_logo->setAutoFillBackground( true );
@@ -202,7 +199,7 @@ VideoWindow::load( const KUrl &url )
 
     KMimeType::Ptr mimeType = KMimeType::findByUrl( url );
     kDebug() << "detected mimetype: " << mimeType->name();
-    if( mimeType->is( "application/x-cd-image" ) || mimeType->is( "inode/directory" ) )
+    if( mimeType->is( QLatin1String( "application/x-cd-image" ) ) || mimeType->is( QLatin1String( "inode/directory" ) ) )
         m_media->setCurrentSource( Phonon::MediaSource( Phonon::Dvd, url.path() ) );
     else
         m_media->setCurrentSource( url );
@@ -239,12 +236,6 @@ VideoWindow::resume()
     return true;
 }
 
-bool
-VideoWindow::mouseUnderWidget()
-{
-	return m_vWidget->underMouse();
-}
-
 
 bool
 VideoWindow::playDvd()
@@ -300,7 +291,7 @@ VideoWindow::playDisc(const Solid::Device& device )
     }
 }
 
-bool 
+bool
 VideoWindow::isPreview(const bool &v)
 {
    if( v )
@@ -362,7 +353,7 @@ VideoWindow::urlOrDisc() const
     {
         case Phonon::MediaSource::Invalid:
         case Phonon::MediaSource::Empty:
-            return "Invalid"; //no i18n, used for DBus responses
+            return QLatin1String( "Invalid" ); //no i18n, used for DBus responses
             break;
         case Phonon::MediaSource::Url:
         case Phonon::MediaSource::LocalFile:
@@ -372,12 +363,12 @@ VideoWindow::urlOrDisc() const
             return source.deviceName();
             break;
         case Phonon::MediaSource::Stream:
-            return "Data Stream";
+            return QLatin1String( "Data Stream" );
             break;
         default:
             break;
     }
-    return "Error";
+    return QLatin1String( "Error" );
 }
 
 QMultiMap<QString, QString>
@@ -464,6 +455,20 @@ VideoWindow::length() const
     return m_media->totalTime();
 }
 
+bool
+VideoWindow::setupAnalyzer(QObject* analyzer)
+{
+    if(!m_aDataOutput)
+    {
+        m_aDataOutput = new Phonon::AudioDataOutput(this);
+        m_audioDataPath = Phonon::createPath(m_media, m_aDataOutput);
+        connect(m_aDataOutput, SIGNAL(dataReady(QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >)),
+                analyzer,  SLOT(drawFrame(QMap<Phonon::AudioDataOutput::Channel,QVector<qint16> >)));
+    }
+
+    return m_audioDataPath.isValid();
+}
+
 bool
 VideoWindow::isDVD() const
 {
@@ -474,6 +479,7 @@ QWidget*
 VideoWindow::newPositionSlider()
 {
     SeekSlider *seekSlider = new SeekSlider();
+    seekSlider->setIconVisible( false );
     seekSlider->setMediaObject( m_media );
     seekSlider->setSingleStep( 5000 );
     return seekSlider;
@@ -483,45 +489,25 @@ QWidget*
 VideoWindow::newVolumeSlider()
 {
     VolumeSlider *volumeSlider = new VolumeSlider();
-    volumeSlider->setObjectName( "volume" );
+    volumeSlider->setObjectName( QLatin1String( "volume" ) );
     volumeSlider->setAudioOutput( m_aOutput );
     volumeSlider->setMuteVisible( false );
     volumeSlider->setOrientation( Qt::Vertical );
     return volumeSlider;
 }
 
-void
-VideoWindow::refreshXineStream()
-{
-   if( m_media->property( "xine_stream_t" ).canConvert<void*>() )
-  //  if( m_media->property( "xine_stream_t" ).isValid() )
-    {
-        kDebug() << "value property " <<  m_media->property( "xine_stream_t" ).type();
-        m_xineStream = (xine_stream_t*) m_media->property( "xine_stream_t" ).value<void*>();
-    }
-    else
-    {
-        kDebug() << "mrrrrrr, QVariant property xine_stream_t isn't a void*.";
-        m_xineStream = 0;
-    }
-}
-
 void
 VideoWindow::stateChanged(Phonon::State currentState, Phonon::State oldstate) // slot
 {
 kDebug() << "chapters: " << m_controller->availableChapters() << " titles: " << m_controller->availableTitles();
     QStringList states;
-    states << "Loading" << "Stopped" << "Playing" << "Buffering" << "Paused" << "Error";
+    states << QLatin1String( "Loading" ) << QLatin1String( "Stopped" ) << QLatin1String( "Playing" ) << QLatin1String( "Buffering" ) << QLatin1String( "Paused" ) << QLatin1String( "Error" );
     kDebug() << "going from " << states.at(oldstate) << " to " << states.at(currentState);
 
-    if( currentState == Phonon::LoadingState )
-      m_xineStream = 0;
-
     if( currentState == Phonon::PlayingState  && m_media->hasVideo() )
     {
         m_logo->hide();
         m_vWidget->show();
-        refreshXineStream();
         updateChannels();
 
         if(m_adjustedSize==false)
@@ -541,19 +527,19 @@ VideoWindow::settingChanged( int setting )
     const QString name = sender()->objectName();
     const double dSetting = static_cast<double>( setting ) * 0.01;
     kDebug() << "setting " << name << " to " << dSetting;
-    if( name == "brightnessSlider" )
+    if( name == QLatin1String( "brightnessSlider" ) )
     {
         m_vWidget->setBrightness( dSetting );
     }
-    else if( name == "contrastSlider" )
+    else if( name == QLatin1String( "contrastSlider" ) )
     {
         m_vWidget->setContrast( dSetting );
     }
-    else if( name == "hueSlider" )
+    else if( name == QLatin1String( "hueSlider" ) )
     {
         m_vWidget->setHue( dSetting );
     }
-    else if( name == "saturationSlider" )
+    else if( name == QLatin1String( "saturationSlider" ) )
     {
         m_vWidget->setSaturation( dSetting );
     }
@@ -598,16 +584,16 @@ VideoWindow::updateActionGroup( QActionGroup* channelActions
         lang->setCheckable( true );
         lang->setText( channel.name() );
         lang->setProperty( TheStream::CHANNEL_PROPERTY, channel.index() );
-        connect( lang, SIGNAL( triggered() ), this, actionSlot );
+        connect( lang, SIGNAL(triggered()), this, actionSlot );
     }
 }
 
 void
 VideoWindow::updateChannels()
 {
-    updateActionGroup( m_subLanguages, m_controller->availableSubtitles(), SLOT( slotSetSubtitle() ) );
+    updateActionGroup( m_subLanguages, m_controller->availableSubtitles(), SLOT(slotSetSubtitle()) );
     emit subChannelsChanged( m_subLanguages->actions() );
-    updateActionGroup( m_audioLanguages, m_controller->availableAudioChannels(), SLOT( slotSetAudio() ) );
+    updateActionGroup( m_audioLanguages, m_controller->availableAudioChannels(), SLOT(slotSetAudio()) );
     emit audioChannelsChanged( m_audioLanguages->actions() );
 }
 
@@ -653,15 +639,8 @@ VideoWindow::slotSetAudio()
 void
 VideoWindow::toggleDVDMenu()
 {
-#ifdef HAVE_XINE
-    if( m_xineStream )
-    {
-        xine_event_t e;
-        e.type = XINE_EVENT_INPUT_MENU1;
-        e.data = NULL;
-        e.data_length = 0;
-        xine_event_send( m_xineStream, &e );
-    }
+#if PHONON_VERSION >= PHONON_VERSION_CHECK(4, 5, 0)
+    m_controller->setCurrentMenu(MediaController::RootMenu);
 #endif
 }
 
@@ -669,19 +648,19 @@ int
 VideoWindow::videoSetting( const QString& setting )
 {
     double dValue = 0.0;
-    if( setting == "brightnessSlider" )
+    if( setting == QLatin1String( "brightnessSlider" ) )
     {
         dValue = m_vWidget->brightness();
     }
-    else if( setting == "contrastSlider" )
+    else if( setting == QLatin1String( "contrastSlider" ) )
     {
         dValue = m_vWidget->contrast();
     }
-    else if( setting == "hueSlider" )
+    else if( setting == QLatin1String( "hueSlider" ) )
     {
         dValue = m_vWidget->hue();
     }
-    else if( setting == "saturationSlider" )
+    else if( setting == QLatin1String( "saturationSlider" ) )
     {
         dValue = m_vWidget->saturation();
     }
@@ -750,8 +729,8 @@ VideoWindow::event( QEvent* event )
       case QEvent::Enter:
       case QEvent::MouseMove:
       case QEvent::MouseButtonPress:
-         kapp->restoreOverrideCursor();
-         m_cursorTimer->start( CURSOR_HIDE_TIMEOUT );
+            kapp->restoreOverrideCursor();
+            m_cursorTimer->start( CURSOR_HIDE_TIMEOUT );
          break;
       default: return QWidget::event( event );
     }
